import SimpleOpenNI.*;

SimpleOpenNI kinect;
GameLogic game;

void setup() {
  
  kinect = new SimpleOpenNI(this);
  kinect.enableDepth();

  // turn on user tracking
  kinect.enableUser(SimpleOpenNI.SKEL_PROFILE_ALL);
  kinect.setMirror(true);
  
  size(640, 480);
  fill(255,0,0);
  textFont(createFont("Georgia", 24));
  
  //start the game
  game = new GameLogic();
}

void draw() {
  
  kinect.update();
//  PImage depth = kinect.depthImage();
//  image(depth, 0, 0);
  
  int currentStage = game.getGameLevel();

  switch(currentStage) {
  
  case 0:
    game.intro();
    break;

  case 1:
    game.play();
    break;

  case 2:
    game.end();
    break;
  }
}//end draw


// user-tracking callbacks!
void onNewUser(int userId) {
  println("start pose detection");
  kinect.startPoseDetection("Psi", userId);
}

void onEndCalibration(int userId, boolean successful) {
  if (successful) { 
    println("  User calibrated !!!");
    kinect.startTrackingSkeleton(userId);
    game.startTime = millis();
    game.gameLevel = 1; //start the game
  } else { 
    println("  Failed to calibrate user !!!");
    kinect.startPoseDetection("Psi", userId);
  }
}

void onStartPose(String pose, int userId) {
  println("Started pose for user");
  kinect.stopPoseDetection(userId); 
  kinect.requestCalibrationSkeleton(userId, true);
  
}

